@@ -38,6 +38,8 @@
 #include <windows.h>
 #endif
 
+#include <glib-object.h>
+
 DL_EXPORT(void) init_giscanner(void);
 
 #define NEW_CLASS(ctype, name, cname)	      \
@@ -720,6 +722,8 @@ init_giscanner(void)
     PyObject *m, *d;
     gboolean is_uninstalled;
 
+    g_type_init ();
+
     /* Hack to avoid having to create a fake directory structure; when
      * running uninstalled, the module will be in the top builddir,
      * with no _giscanner prefix.
