@@ -137,7 +137,6 @@ foo_sub_interface_do_moo (FooSubInterface *self, int x, gpointer y)
  * @self:
  * @callback: (scope call):
  * @user_data:
- *
  */
 void
 foo_sub_interface_do_baz (FooSubInterface *self, GCallback callback, gpointer user_data)
@@ -523,6 +522,7 @@ foo_test_string_array_with_g (gchar **array)
 
 /**
  * foo_test_array:
+ *
  * Returns: (element-type utf8) (transfer container):
  */
 GArray *
@@ -782,3 +782,17 @@ foo_object_append_new_stack_layer (FooObject *obj, int x)
 {
   return NULL;
 }
+
+/**
+ * foo_not_a_constructor_new:
+ *
+ * This should be scanned as a top-level function, and shouldn't cause
+ * a "Can't find matching type for constructor" warning.
+ *
+ * Returns: (transfer none):
+ */
+FooObject *
+foo_not_a_constructor_new (void)
+{
+  return NULL;
+}
